@@ -17,7 +17,6 @@
 #include "settings.h"
 #include "utils/slconfig.h"
 #include "utils/conversion.h"
-#include "defines.h"
 
 #include "utils/platform.h"
 #include "utils/slpaths.h"
@@ -26,17 +25,17 @@
 SLCONFIG("/ChatLog/chatlog_enable", true, "Log chat messages");
 #endif
 
-ChatLog::ChatLog():
-	m_active(false)
+ChatLog::ChatLog()
+    : m_active(false)
 {
 }
 
-ChatLog::ChatLog(const wxString& logname):
-	m_logname(logname),
-	m_active ( LogEnabled() ),
-	m_logfile ( )
+ChatLog::ChatLog(const wxString& logname)
+    : m_logname(logname)
+    , m_active(LogEnabled())
+    , m_logfile()
 {
-	wxLogMessage( _T( "ChatLog::ChatLog( %s )" ), logname.c_str());
+	wxLogMessage(_T( "ChatLog::ChatLog( %s )" ), logname.c_str());
 	SetLogFile(logname);
 }
 
@@ -48,7 +47,7 @@ bool ChatLog::SetLogFile(const wxString& logname)
 		return true;
 	}
 
-	m_logname.Replace( wxT( ":" ), wxT( "_" ) );
+	m_logname.Replace(wxT(":"), wxT("_"));
 	if (logname != m_logname) {
 		if (m_logfile.IsOpened()) {
 			CloseSession();
@@ -61,17 +60,17 @@ bool ChatLog::SetLogFile(const wxString& logname)
 
 ChatLog::~ChatLog()
 {
-	wxLogMessage( _T( "%s -- ChatLog::~ChatLog()" ), m_logname.c_str() );
+	wxLogMessage(_T( "%s -- ChatLog::~ChatLog()" ), m_logname.c_str());
 	CloseSession();
 }
 
 void ChatLog::CloseSession()
 {
-	if (!m_logfile.IsOpened() ) {
+	if (!m_logfile.IsOpened()) {
 		return;
 	}
 
-	AddMessage(wxEmptyString, _( "### Session Closed at [%Y-%m-%d %H:%M]" ));
+	AddMessage(wxEmptyString, _("### Session Closed at [%Y-%m-%d %H:%M]"));
 	m_logfile.Flush();
 	m_active = false;
 	m_logfile.Close();
@@ -86,7 +85,7 @@ bool ChatLog::AddMessage(const wxString& text, const wxString& timeformat)
 		return false;
 	}
 	wxString logtime = wxDateTime::Now().Format(timeformat);
-	const bool res = m_logfile.Write( logtime + text + wxTextBuffer::GetEOL(), wxConvUTF8);
+	const bool res = m_logfile.Write(logtime + text + wxTextBuffer::GetEOL(), wxConvUTF8);
 	if (!res) {
 		wxLogWarning(_T("Couldn't write to %s"), m_logname.c_str());
 		m_logfile.Close();
@@ -98,8 +97,8 @@ bool ChatLog::AddMessage(const wxString& text, const wxString& timeformat)
 bool ChatLog::CreateCurrentLogFolder()
 {
 	const wxString path = wxFileName(GetCurrentLogfilePath()).GetPath();
-	if ( !wxFileName::Mkdir( path, 0755, wxPATH_MKDIR_FULL) ) {
-		wxLogWarning( _T( "can't create logging folder: %s" ), path.c_str() );
+	if (!wxFileName::Mkdir(path, 0755, wxPATH_MKDIR_FULL)) {
+		wxLogWarning(_T( "can't create logging folder: %s" ), path.c_str());
 		m_active = false;
 		return false;
 	}
@@ -108,8 +107,8 @@ bool ChatLog::CreateCurrentLogFolder()
 
 bool ChatLog::OpenLogFile()
 {
-	wxLogMessage( _T( "OpenLogFile( ) %s" ), m_logname.c_str() ) ;
-	wxString logFilePath ( GetCurrentLogfilePath() );
+	wxLogMessage(_T( "OpenLogFile( ) %s" ), m_logname.c_str());
+	wxString logFilePath(GetCurrentLogfilePath());
 
 	if (!LogEnabled()) {
 		return true;
@@ -120,13 +119,13 @@ bool ChatLog::OpenLogFile()
 	}
 
 	if (!wxFile::Exists(logFilePath)) {
-		m_logfile.Create( logFilePath);
+		m_logfile.Create(logFilePath);
 	} else {
 		m_logfile.Open(logFilePath, wxFile::read_write);
 	}
 
-	if ( !m_logfile.IsOpened() ) {
-		wxLogWarning( _T( "Can't open log file %s" ), logFilePath.c_str() ) ;
+	if (!m_logfile.IsOpened()) {
+		wxLogWarning(_T( "Can't open log file %s" ), logFilePath.c_str());
 		m_active = false;
 		return false;
 	}
@@ -137,7 +136,7 @@ bool ChatLog::OpenLogFile()
 	return AddMessage(wxEmptyString, _T( "### Session Start at [%Y-%m-%d %H:%M]" ));
 }
 
-const wxArrayString& ChatLog::GetLastLines( ) const
+const wxArrayString& ChatLog::GetLastLines() const
 {
 	return m_last_lines;
 }
@@ -146,7 +145,7 @@ const wxArrayString& ChatLog::GetLastLines( ) const
 wxString ChatLog::GetCurrentLogfilePath() const
 {
 #ifdef TEST
-	return wxFileName::GetTempDir()+_T("/sltest.log");
+	return wxFileName::GetTempDir() + _T("/sltest.log");
 #else
 	return TowxString(SlPaths::GetChatLogLoc()) + sett().GetDefaultServer() + wxFileName::GetPathSeparator() + m_logname + _T( ".txt" );
 #endif
@@ -165,11 +164,11 @@ bool ChatLog::LogEnabled()
 static inline ssize_t readblock(wxFile& fd, void* buffer, size_t size, off_t offset)
 {
 	assert(offset >= 0);
-	if ( offset < 0 ) {
+	if (offset < 0) {
 		return -1;
 	}
 
-	if ( fd.Seek(offset) != offset ) {
+	if (fd.Seek(offset) != offset) {
 		return -1;
 	}
 
@@ -180,7 +179,7 @@ static inline ssize_t readblock(wxFile& fd, void* buffer, size_t size, off_t off
 /** Calculate the next read position for find_tail_sequences (below) */
 static inline off_t next_read_position(off_t last_read_position, size_t read_size, size_t read_overlap)
 {
-	return std::max(static_cast<long signed int>(last_read_position - read_size - read_overlap), (long signed int) 0);
+	return std::max(static_cast<long signed int>(last_read_position - read_size - read_overlap), (long signed int)0);
 }
 
 /** Find an arbitrary number of delimited strings at the end of a file.  This
@@ -198,7 +197,7 @@ static inline off_t next_read_position(off_t last_read_position, size_t read_siz
  */
 static size_t find_tail_sequences(wxFile& fd, const char* bytes, size_t bytes_length, size_t count, wxArrayString& out)
 {
-	size_t count_added ( 0 );
+	size_t count_added(0);
 
 	/* We overlap the file reads a little to avoid splitting (and thus missing) the
 	   delimiter sequence.  */
@@ -209,29 +208,29 @@ static size_t find_tail_sequences(wxFile& fd, const char* bytes, size_t bytes_le
 	bool have_last_pos = false;
 	char buf[read_size];
 	off_t last_found_pos = 0;
-	off_t last_read_position = log_length + read_overlap ;
+	off_t last_read_position = log_length + read_overlap;
 
 	/* We read `read_size'-byte blocks of the file, starting at the end and working backwards. */
-	while ( count_added < count && last_read_position > 0 ) {
+	while (count_added < count && last_read_position > 0) {
 		const off_t read_position = next_read_position(last_read_position, read_size, read_overlap);
 		const size_t bytes_read = readblock(fd, buf, std::min(static_cast<off_t>(read_size), last_read_position - read_position), read_position);
 
 		/* In each block, we search for `bytes', starting at the end.  */
-		for ( ssize_t i = bytes_read - read_overlap - 1; i >= 0; i-- ) {
-			if ( strncmp((buf + i), bytes, bytes_length) == 0 ) {
-				const off_t this_found_pos  = read_position + i;
+		for (ssize_t i = bytes_read - read_overlap - 1; i >= 0; i--) {
+			if (strncmp((buf + i), bytes, bytes_length) == 0) {
+				const off_t this_found_pos = read_position + i;
 
 				if (have_last_pos) {
 					const size_t line_length = last_found_pos - this_found_pos - bytes_length;
 
-					if ( line_length > 0 ) {
+					if (line_length > 0) {
 						char* source = NULL;
 
-						if ( last_found_pos >= read_position + (off_t) bytes_read ) {
-							source = new char[ line_length + 1];
+						if (last_found_pos >= read_position + (off_t)bytes_read) {
+							source = new char[line_length + 1];
 							memset(source, 0, line_length + 1);
 
-							if ( readblock(fd, source, line_length, this_found_pos + bytes_length) < (ssize_t) line_length ) {
+							if (readblock(fd, source, line_length, this_found_pos + bytes_length) < (ssize_t)line_length) {
 								wxLogWarning(_T("ChatLog::find_tail_sequences: Read-byte count less than expected"));
 							}
 						} else {
@@ -240,11 +239,11 @@ static size_t find_tail_sequences(wxFile& fd, const char* bytes, size_t bytes_le
 						source[line_length] = 0;
 						wxString tmp = wxString::FromUTF8(source);
 						out.Insert(tmp, 0);
-						if ( last_found_pos >= read_position + (off_t) bytes_read )
+						if (last_found_pos >= read_position + (off_t)bytes_read)
 							delete[] source;
 
 						count_added++;
-						if ( count_added >= count )
+						if (count_added >= count)
 							break;
 					}
 				}
@@ -263,25 +262,31 @@ static size_t find_tail_sequences(wxFile& fd, const char* bytes, size_t bytes_le
 
 void ChatLog::FillLastLineArray()
 {
-	if (!m_logfile.IsOpened() ) {
+	m_last_lines.Clear();
+
+	if (!m_logfile.IsOpened()) {
 		wxLogError(_T("%s: failed to open log file."), __PRETTY_FUNCTION__);
 		return;
 	}
+
+	if (m_logfile.Length() <= 0) {
+		return;
+	}
+
 #ifdef TEST
 	const size_t num_lines = 6;
 #else
 	const size_t num_lines = sett().GetAutoloadedChatlogLinesCount();
 #endif
 
-	m_last_lines.Clear();
 	m_last_lines.Alloc(num_lines);
 
-	const wxChar* wc_EOL ( wxTextBuffer::GetEOL() );
-	const size_t eol_num_chars ( wxStrlen(wc_EOL) );
+	const wxChar* wc_EOL(wxTextBuffer::GetEOL());
+	const size_t eol_num_chars(wxStrlen(wc_EOL));
 #ifndef WIN32
-	char* eol ( static_cast<char*>( alloca(eol_num_chars) ) );
+	char* eol(static_cast<char*>(alloca(eol_num_chars)));
 #else
-	char* eol ( new char[eol_num_chars] );
+	char* eol(new char[eol_num_chars]);
 #endif
 	wxConvUTF8.WC2MB(eol, wc_EOL, eol_num_chars);
 
