@@ -40,53 +40,56 @@ std::string PrDownloader::GetEngineCat()
 class DownloadItem : public LSL::WorkItem
 {
 public:
-	DownloadItem( std::list<IDownload*> item, IDownloader* loader)
-		: m_item(item)
-		, m_loader(loader)
-	{}
+	DownloadItem(std::list<IDownload*> item, IDownloader* loader)
+	    : m_item(item)
+	    , m_loader(loader)
+	{
+	}
 
-	void Run() {
+	void Run()
+	{
 		if (!m_item.empty()) {
 			UiEvents::ScopedStatusMessage msg("Downloading: " + m_item.front()->name, 0);
 			//we create this in avance cause m_item gets freed
 			wxString d(_("Download complete: "));
 			d += TowxString(m_item.front()->name);
-			m_loader->download( m_item, sett().GetHTTPMaxParallelDownloads() );
+			m_loader->download(m_item, sett().GetHTTPMaxParallelDownloads());
 			std::list<IDownload*>::iterator it;
 			bool reload = false;
 			bool lobbydl = false;
-			for( it = m_item.begin(); it!=m_item.end(); ++it) {
+			for (it = m_item.begin(); it != m_item.end(); ++it) {
 				IDownload* dl = *it;
-				switch(dl->cat) {
-				case IDownload::CAT_ENGINE_LINUX:
-				case IDownload::CAT_ENGINE_WINDOWS:
-				case IDownload::CAT_ENGINE_LINUX64:
-				case IDownload::CAT_ENGINE_MACOSX: {
-					fileSystem->extractEngine(dl->name, dl->version);
-					SlPaths::RefreshSpringVersionList(); //FIXME: maybe not thread-save!
-					SlPaths::SetUsedSpringIndex(dl->version);
-					break;
-				}
-				case IDownload::CAT_LOBBYCLIENTS:
-					lobbydl = true;
-					fileSystem->extract(dl->name, SlPaths::GetUpdateDir(), true);
-					break;
-				case IDownload::CAT_MAPS:
-				case IDownload::CAT_GAMES:
-					reload = true;
-					break;
-				default:
-					break;;
+				switch (dl->cat) {
+					case IDownload::CAT_ENGINE_LINUX:
+					case IDownload::CAT_ENGINE_WINDOWS:
+					case IDownload::CAT_ENGINE_LINUX64:
+					case IDownload::CAT_ENGINE_MACOSX: {
+						fileSystem->extractEngine(dl->name, dl->version);
+						SlPaths::RefreshSpringVersionList(); //FIXME: maybe not thread-save!
+						SlPaths::SetUsedSpringIndex(dl->version);
+						break;
+					}
+					case IDownload::CAT_LOBBYCLIENTS:
+						lobbydl = true;
+						fileSystem->extract(dl->name, SlPaths::GetUpdateDir(), true);
+						break;
+					case IDownload::CAT_MAPS:
+					case IDownload::CAT_GAMES:
+						reload = true;
+						break;
+					default:
+						break;
+						;
 				}
 			}
-			m_loader->freeResult( m_item );
+			m_loader->freeResult(m_item);
 			UiEvents::ScopedStatusMessage msgcomplete(d, 0);
 			if (reload) {
 				LSL::usync().ReloadUnitSyncLib();
 				// prefetch map data after a download as well
-				for( it = m_item.begin(); it!=m_item.end(); ++it) {
+				for (it = m_item.begin(); it != m_item.end(); ++it) {
 					IDownload* dl = *it;
-					switch(dl->cat) {
+					switch (dl->cat) {
 						case IDownload::CAT_MAPS: {
 							LSL::usync().PrefetchMap(dl->name); //FIXME: do the same for games, too
 						}
@@ -123,18 +126,19 @@ private:
 };
 
 SearchItem::SearchItem(std::list<IDownloader*> loaders, const std::string name, IDownload::category cat)
-	: m_loaders(loaders)
-	, m_name(name)
-	, m_cat(cat)
-	, m_result_size(0)
-{}
+    : m_loaders(loaders)
+    , m_name(name)
+    , m_cat(cat)
+    , m_result_size(0)
+{
+}
 
 void SearchItem::Run()
 {
 	rapidDownload->setOption("forceupdate", "");
 	std::list<IDownload*> results;
 	std::list<IDownloader*>::const_iterator it = m_loaders.begin();
-	for( ; it != m_loaders.end(); ++it ) {
+	for (; it != m_loaders.end(); ++it) {
 		(*it)->search(results, m_name, m_cat);
 		if (!results.empty()) {
 			DownloadItem* dl_item = new DownloadItem(results, *it);
@@ -143,21 +147,22 @@ void SearchItem::Run()
 			return;
 		}
 	}
+	wxLogError(wxString::Format("Item (%s) requested for download could not be found. Sorry.", m_name.c_str()));
 	return;
 }
 
 
-PrDownloader::PrDownloader():
-	wxEvtHandler(),
-	m_dl_thread(new LSL::WorkerThread())
+PrDownloader::PrDownloader()
+    : wxEvtHandler()
+    , m_dl_thread(new LSL::WorkerThread())
 {
 	IDownloader::Initialize(&downloadsObserver());
 	UpdateSettings();
 	m_game_loaders.push_back(rapidDownload);
 	m_game_loaders.push_back(httpDownload);
-	m_game_loaders.push_back(plasmaDownload);
+	//	m_game_loaders.push_back(plasmaDownload);
 	m_map_loaders.push_back(httpDownload);
-	m_map_loaders.push_back(plasmaDownload);
+	//	m_map_loaders.push_back(plasmaDownload);
 	ConnectGlobalEvent(this, GlobalEvent::OnSpringStarted, wxObjectEventFunction(&PrDownloader::OnSpringStarted));
 	ConnectGlobalEvent(this, GlobalEvent::OnSpringTerminated, wxObjectEventFunction(&PrDownloader::OnSpringTerminated));
 }
@@ -179,23 +184,28 @@ void PrDownloader::UpdateSettings()
 	rapidDownload->setOption("masterurl", STD_STRING(cfg().ReadString(_T("/Spring/RapidMasterUrl"))));
 }
 
-void PrDownloader::RemoveTorrentByName(const std::string &/*name*/)
+void PrDownloader::RemoveTorrentByName(const std::string& /*name*/)
 {
 }
 
-int PrDownloader::GetDownload(const std::string& category, const std::string &name)
+int PrDownloader::GetDownload(const std::string& category, const std::string& name)
 {
-	if (category == "map") {
+	std::string cat = category;
+	if (category == "engine") { //automaticly select engine from current platform
+		cat = PrDownloader::GetEngineCat();
+	}
+
+	if (cat == "map") {
 		return Get(m_map_loaders, name, IDownload::CAT_MAPS);
-	} else if (category == "game") {
+	} else if (cat == "game") {
 		return Get(m_game_loaders, name, IDownload::CAT_GAMES);
-	} else if (category == "engine_linux") {
+	} else if (cat == "engine_linux") {
 		return Get(m_map_loaders, name, IDownload::CAT_ENGINE_LINUX);
-	} else if (category == "engine_linux64") {
+	} else if (cat == "engine_linux64") {
 		return Get(m_map_loaders, name, IDownload::CAT_ENGINE_LINUX64);
-	} else if (category == "engine_windows") {
+	} else if (cat == "engine_windows") {
 		return Get(m_map_loaders, name, IDownload::CAT_ENGINE_WINDOWS);
-	} else if (category == "engine_macosx") {
+	} else if (cat == "engine_macosx") {
 		return Get(m_map_loaders, name, IDownload::CAT_ENGINE_MACOSX);
 	}
 	wxLogError(_T("Category %s not found"), category.c_str());
@@ -229,7 +239,7 @@ void PrDownloader::OnSpringTerminated(wxCommandEvent& /*data*/)
 	//FIXME: resume downloads
 }
 
-int PrDownloader::Get(std::list<IDownloader*> loaders, const std::string &name, IDownload::category cat)
+int PrDownloader::Get(std::list<IDownloader*> loaders, const std::string& name, IDownload::category cat)
 {
 	SearchItem* searchItem = new SearchItem(loaders, name, cat);
 	m_dl_thread->DoWork(searchItem);
@@ -238,8 +248,8 @@ int PrDownloader::Get(std::list<IDownloader*> loaders, const std::string &name,
 
 PrDownloader& prDownloader()
 {
-	static LSL::Util::LineInfo<PrDownloader> m( AT );
-	static LSL::Util::GlobalObjectHolder<PrDownloader, LSL::Util::LineInfo<PrDownloader> > s_PrDownloader( m );
+	static LSL::Util::LineInfo<PrDownloader> m(AT);
+	static LSL::Util::GlobalObjectHolder<PrDownloader, LSL::Util::LineInfo<PrDownloader> > s_PrDownloader(m);
 	return s_PrDownloader;
 }
 
