@@ -3,22 +3,32 @@
 #ifndef SPRINGLOBBY_HEADERGUARD_INETCLASS_H
 #define SPRINGLOBBY_HEADERGUARD_INETCLASS_H
 
-class Socket;
-
 //! @brief Abstract baseclass that is used when needed to interface with socket class
 class iNetClass
 {
 public:
+	iNetClass()
+	{
+	}
+	virtual ~iNetClass()
+	{
+	}
 
-	iNetClass() {}
-	virtual ~iNetClass() {}
-
-	virtual void OnConnected( Socket& /*sock*/ ) {}
-	virtual void OnDisconnected( Socket& /*sock*/ ) {}
-	virtual void OnDataReceived( Socket& /*sock*/ ) {}
-	virtual void OnError(const wxString& /*error*/) {}
-	virtual void Ping() {}
+	virtual void OnConnected()
+	{
+	}
+	virtual void OnDisconnected()
+	{
+	}
+	virtual void OnDataReceived()
+	{
+	}
+	virtual void OnError(const std::string& /*error*/)
+	{
+	}
+	virtual void Ping()
+	{
+	}
 };
 
 #endif // SPRINGLOBBY_HEADERGUARD_INETCLASS_H
-
