@@ -22,6 +22,7 @@
 #include <lslutils/conversion.h>
 #include <lslutils/misc.h>
 #include <lslutils/globalsmanager.h>
+#include <lslutils/thread.h>
 
 #define LOCK_UNITSYNC boost::mutex::scoped_lock lock_criticalsection(m_lock)
 
@@ -908,8 +909,8 @@ protected:
 	Unitsync* m_usync;
 
 	GetMapImageAsyncResult( Unitsync* usync, const std::string& mapname, int evtId ):
-		m_usync(usync),
-		m_mapname(mapname.c_str())
+		m_mapname(mapname.c_str()),
+		m_usync(usync)
 	{}
 private:
 
