@@ -239,6 +239,18 @@ lslColor GetFreeColor( const ConstCommonUserPtr /*user*/ )
     return lslColor();
 }
 
+void Replace(std::string & str, const std::string& from, const std::string& to)
+{
+	if(from.empty())
+		return;
+	size_t start_pos = 0;
+	while((start_pos = str.find(from, start_pos)) != std::string::npos) {
+		str.replace(start_pos, from.length(), to);
+		start_pos += to.length(); // In case 'to' contains 'from', like replacing 'x' with 'yx'
+	}
+}
+
+
 } //namespace Util
 
 
