@@ -180,6 +180,8 @@ std::string AfterFirst( const std::string& phrase, const std::string& searchterm
 std::string ParentPath( const std::string& path);
 //! ensures path ends with (back)slash
 std::string EnsureDelimiter(const std::string& path);
+//! search string for from and replace with to
+void Replace(std::string & str, const std::string& from, const std::string& to);
 
 
 //! get a list of minimum numteam colors have maximum total difference in a certain metric
@@ -227,12 +229,29 @@ public:
 	{
 	}
 
+	// from lobbyprotocol
+	//color is a 32-bit signed integer in decimal form (e.g. 255 and not FF) where each color channel should occupy 1 byte
+	//(e.g. in hexdecimal: $00BBGGRR, B = blue, G = green, R = red). Example: 255 stands for $000000FF.
+	lslColor(int color)
+	{
+		r = (color      ) & 0xff;
+		g = (color >> 8 ) & 0xff;
+		b = (color >> 16) & 0xff;
+		a = 0xff; // alpha isn't supported by lobby protocol
+	}
+
+	int GetLobbyColor() const{
+        return /*(a << 24) +*/ (b << 16) + (g << 8) + r;
+	}
+
 	bool operator == (const lslColor& o) const {
 		return r == o.r && 	g == o.g && b == o.b && a == o.a;
 	}
+
 	bool operator != (const lslColor& o) const {
 		return !(this->operator ==(o));
 	}
+
 	unsigned char Red()   const { return r; }
 	unsigned char Green() const { return g; }
 	unsigned char Blue()  const { return b; }
