@@ -24,8 +24,11 @@ lsl/container/userlist.cpp
 
 const UserList::user_map_t::size_type SEEKPOS_INVALID = UserList::user_map_t::size_type(-1);
 
-UserList::UserList(): m_seek(m_users.end()), m_seekpos(SEEKPOS_INVALID)
-{ }
+UserList::UserList()
+    : m_seek(m_users.end())
+    , m_seekpos(SEEKPOS_INVALID)
+{
+}
 
 /*
 UserList& UserList::operator= (const UserList&& other)
@@ -41,51 +44,54 @@ UserList& UserList::operator= (const UserList&& other)
 }
 */
 
-void UserList::AddUser( User& user )
+void UserList::AddUser(User& user)
 {
-  m_users[user.GetNick()] = &user;
-  m_seekpos = SEEKPOS_INVALID;
+	m_users[user.GetNick()] = &user;
+	m_seekpos = SEEKPOS_INVALID;
 }
 
-void UserList::RemoveUser( const std::string& nick )
+void UserList::RemoveUser(const std::string& nick)
 {
-  m_users.erase(nick);
-  m_seekpos = SEEKPOS_INVALID;
+	m_users.erase(nick);
+	m_seekpos = SEEKPOS_INVALID;
 }
 
-User& UserList::GetUser( const std::string& nick ) const
+User& UserList::GetUser(const std::string& nick) const
 {
-  user_const_iter_t u = m_users.find(nick);
-  ASSERT_EXCEPTION( u != m_users.end(), _T("UserList::GetUser(\"") + TowxString(nick) + _T("\"): no such user") );
-  //ASSERT_LOGIC( u != m_users.end(), _T("UserList::GetUser(\"") + nick + _T("\"): no such user") );
-  return *u->second;
+	user_const_iter_t u = m_users.find(nick);
+	//ASSERT_EXCEPTION( u != m_users.end(), _T("UserList::GetUser(\"") + TowxString(nick) + _T("\"): no such user") );
+	if (u == m_users.end()) {
+		wxLogWarning(_T("UserList::GetUser(\"") + TowxString(nick) + _T("\"): no such user"));
+	}
+	//ASSERT_LOGIC( u != m_users.end(), _T("UserList::GetUser(\"") + nick + _T("\"): no such user") );
+	return *u->second;
 }
 
-User& UserList::GetUser( user_map_t::size_type index ) const
+User& UserList::GetUser(user_map_t::size_type index) const
 {
-  if ((m_seekpos == SEEKPOS_INVALID) || (m_seekpos > index)) {
-    m_seek = m_users.begin();
-    m_seekpos = 0;
-  }
-  std::advance( m_seek, index - m_seekpos );
-  m_seekpos = index;
-  return *m_seek->second;
+	if ((m_seekpos == SEEKPOS_INVALID) || (m_seekpos > index)) {
+		m_seek = m_users.begin();
+		m_seekpos = 0;
+	}
+	std::advance(m_seek, index - m_seekpos);
+	m_seekpos = index;
+	return *m_seek->second;
 }
 
-bool UserList::UserExists( std::string const& nick ) const
+bool UserList::UserExists(std::string const& nick) const
 {
-  return m_users.find(nick) != m_users.end();
+	return m_users.find(nick) != m_users.end();
 }
 
 UserList::user_map_t::size_type UserList::GetNumUsers() const
 {
-  return m_users.size();
+	return m_users.size();
 }
 
 void UserList::Nullify()
 {
-    for( user_map_t::iterator it = m_users.begin(); it != m_users.begin(); ++it ) {
-        delete it->second;
-        it->second = NULL;
-    }
+	for (user_map_t::iterator it = m_users.begin(); it != m_users.begin(); ++it) {
+		delete it->second;
+		it->second = NULL;
+	}
 }
