@@ -16,81 +16,80 @@
 
 bool SafeMkdir(const wxString& dir)
 {
-    if (!wxDirExists(dir))
-        return wxMkdir(dir);
+	if (!wxDirExists(dir))
+		return wxMkdir(dir);
 	return true;
 }
 
 void ErrorMsgBox(const wxString& err, bool silent)
 {
 	if (!silent) {
-		wxMessageBox(err, _T("Error") );
+		wxMessageBox(err, _T("Error"));
 	}
 }
 
-bool MoveDirWithFilebackupRename( wxString from, wxString to, bool backup, bool silent)
+bool MoveDirWithFilebackupRename(wxString from, wxString to, bool backup, bool silent)
 {
-    // first make sure that the source dir exists
-    if(!wxDir::Exists(from)) {
-			ErrorMsgBox(from + _T(" does not exist.  Can not copy directory."), silent);
-            return false;
-    }
+	// first make sure that the source dir exists
+	if (!wxDir::Exists(from)) {
+		ErrorMsgBox(from + _T(" does not exist.  Can not copy directory."), silent);
+		return false;
+	}
 
 	if (from == to) {
 		ErrorMsgBox(_T("Cannot copy: source == destination: ") + from, silent);
 		return false;
 	}
 
-	if (from.empty() || to.empty()){
+	if (from.empty() || to.empty()) {
 		ErrorMsgBox(_T("Cannot copy empty directory"), silent);
 		return false;
 	}
 
-    SafeMkdir(to);
+	SafeMkdir(to);
 
-    wxString sep = wxFileName::GetPathSeparator();
+	wxString sep = wxFileName::GetPathSeparator();
 
-    wxDir dir(from);
-    wxString filename;
-    if (!dir.GetFirst(&filename)) {
+	wxDir dir(from);
+	wxString filename;
+	if (!dir.GetFirst(&filename)) {
 		return false;
 	}
 
-    // append a slash if there is not one (for easier parsing)
-    // because who knows what people will pass to the function.
-    if ( !to.EndsWith( sep ) ) {
-            to += sep;
-    }
-    // for both dirs
-    if ( !from.EndsWith( sep ) ) {
-            from += sep;
-    }
+	// append a slash if there is not one (for easier parsing)
+	// because who knows what people will pass to the function.
+	if (!to.EndsWith(sep)) {
+		to += sep;
+	}
+	// for both dirs
+	if (!from.EndsWith(sep)) {
+		from += sep;
+	}
 
 	do {
-		if (wxDirExists(from + filename) )
-		{
+		if (wxDirExists(from + filename)) {
 			MoveDirWithFilebackupRename(from + filename, to + filename, false, silent); //no backup in subdirs
-		} else{
+		} else {
 			//if files exists move it to backup, this way we can use this func on windows to replace 'active' files
-			if ( backup && wxFileExists( to + filename ) ) {
+			if (backup && wxFileExists(to + filename)) {
 				//delete prev backup
-				if ( wxFileExists( to + filename + _T(".old") ) ) {
-					wxRemoveFile( to + filename + _T(".old")  );
+				if (wxFileExists(to + filename + _T(".old"))) {
+					wxRemoveFile(to + filename + _T(".old"));
 				}
 				//make backup
-				if ( !wxRenameFile( to + filename, to + filename + _T(".old") ) ) {
-					ErrorMsgBox( _T("could not rename %s, copydir aborted") + to + filename, silent);
+				if (!wxRenameFile(to + filename, to + filename + _T(".old"))) {
+					ErrorMsgBox(_T("could not rename %s, copydir aborted") + to + filename, silent);
 					return false;
 				}
 			}
 			//do the actual copy
-			if ( !wxCopyFile(from + filename, to + filename, true) ) {
-				ErrorMsgBox( _T("could not copy %s to %s, copydir aborted") + from + filename + _T("\n") + to + filename, silent);
+			if (!wxCopyFile(from + filename, to + filename, true)) {
+				ErrorMsgBox(_T("could not copy %s to %s, copydir aborted") + from + filename + _T("\n") + to + filename, silent);
 				return false;
 			}
 		}
-	} while (dir.GetNext(&filename) );
-    return true;
+	} while (dir.GetNext(&filename));
+	return true;
 }
 
 #ifdef __WXMSW__
@@ -101,13 +100,13 @@ bool MoveDirWithFilebackupRename( wxString from, wxString to, bool backup, bool
 
 bool IsPreVistaWindows()
 {
-    return wxPlatformInfo().GetOSMajorVersion() < 6;
+	return wxPlatformInfo().GetOSMajorVersion() < 6;
 }
 
 bool IsUACenabled()
 {
-    wxRegKey UACpath( _T("HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Policies\\System") ); // check if UAC is on, skip dialog if not
-    if(!UACpath.Exists() ) {
+	wxRegKey UACpath(_T("HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Policies\\System")); // check if UAC is on, skip dialog if not
+	if (!UACpath.Exists()) {
 		return false;
 	}
 
@@ -117,25 +116,25 @@ bool IsUACenabled()
 	}
 
 	long value;
-	if( UACpath.QueryValue(LUA, &value ) ) { // reg key not present -> not vista
-		if( value != 0 ) {
+	if (UACpath.QueryValue(LUA, &value)) { // reg key not present -> not vista
+		if (value != 0) {
 			return true;
 		}
 	}
 
-    return false;
+	return false;
 }
 #endif
 
 
-CwdGuard::CwdGuard( const wxString& new_cwd )
-    : m_old_cwd( wxGetCwd() )
+CwdGuard::CwdGuard(const wxString& new_cwd)
+    : m_old_cwd(wxGetCwd())
 {
-    wxSetWorkingDirectory( new_cwd );
+	wxSetWorkingDirectory(new_cwd);
 }
 CwdGuard::~CwdGuard()
 {
-    wxSetWorkingDirectory( m_old_cwd );
+	wxSetWorkingDirectory(m_old_cwd);
 }
 
 static wxString escapeStr(const wxString& str)
@@ -143,7 +142,7 @@ static wxString escapeStr(const wxString& str)
 	if (str.Find(_T(" ")) == wxNOT_FOUND) {
 		return str;
 	}
-	if (str.StartsWith(_T("\"")) && str.EndsWith(_T("\""))){ //no double escape
+	if (str.StartsWith(_T("\"")) && str.EndsWith(_T("\""))) { //no double escape
 		return str;
 	}
 	return _T("\"") + str + _T("\"");
@@ -152,7 +151,7 @@ static wxString escapeStr(const wxString& str)
 int RunProcess(const wxString& cmd, const wxArrayString& params, const bool async, const bool root)
 {
 	wxString paramstring;
-	for (wxString param: params) {
+	for (wxString param : params) {
 		if (!paramstring.empty()) {
 			paramstring += _T(" ");
 		}
@@ -173,13 +172,14 @@ int RunProcess(const wxString& cmd, const wxArrayString& params, const bool asyn
 	ShExecInfo.hInstApp = NULL;
 
 	if (root && IsUACenabled()) {
-		if (!IsPreVistaWindows() )
+		if (!IsPreVistaWindows())
 			ShExecInfo.lpVerb = _T("runas");
 	}
 
 	int res = ShellExecuteEx(&ShExecInfo);
-	if (async) return (res > 32);
-	WaitForSingleObject(ShExecInfo.hProcess,INFINITE);
+	if (async)
+		return (res > 32);
+	WaitForSingleObject(ShExecInfo.hProcess, INFINITE);
 	GetExitCodeProcess(ShExecInfo.hProcess, &exitCode);
 	return exitCode;
 #else
@@ -187,7 +187,7 @@ int RunProcess(const wxString& cmd, const wxArrayString& params, const bool asyn
 	if (!paramstring.empty()) {
 		realcmd += _T(" ") + paramstring;
 	}
-	return system( realcmd.mb_str( wxConvUTF8 ) );
+	return system(realcmd.mb_str(wxConvUTF8));
 #endif
 }
 
@@ -205,18 +205,28 @@ int BrowseFolder(const wxString& path)
 #endif
 }
 
+#ifndef __WXMSW__
+#include <signal.h>
+#include <time.h>
+#endif
 int WaitForExit(int pid)
 {
 #ifdef __WXMSW__
 	HANDLE h = OpenProcess(0, false, pid);
 	if (h == NULL) {
-        return 0;
+		return 0;
 	}
 	WaitForSingleObject(h, INFINITE);
 	DWORD exitCode = 0;
 	GetExitCodeProcess(h, &exitCode);
 	CloseHandle(h);
 	return exitCode;
+#else
+	struct timespec delay;
+	delay.tv_sec = 0;
+	delay.tv_nsec = 100000; // 100ms
+	while ((kill(pid, 0) == 0) && (nanosleep(&delay, NULL) == 0)) {
+	}
 #endif
 	return 0;
 }
